@@ -7,7 +7,7 @@ from fastapi import Query
 from progress.bar import Bar
 from pydantic import BaseModel
 from pydantic.dataclasses import dataclass
-from pyimporters_plugins.base import KnowledgeParserBase, KnowledgeParserOptions, Term
+from pyimporters_plugins.base import KnowledgeParserBase, KnowledgeParserOptions, Term, maybe_archive
 from rdflib import Graph, RDF, SKOS
 from rdflib.resource import Resource
 
@@ -38,24 +38,26 @@ class SKOSKnowledgeParser(KnowledgeParserBase):
         bar.max = 20
         bar.start()
         g = Graph()
-        thes = g.parse(source=str(source), format=options.rdf_format)
-        bar.next(20)
-        bar.max = len(list(thes.subjects(predicate=RDF.type, object=SKOS.Concept)))
-        for curi in thes[:RDF.type:SKOS.Concept]:
-            bar.next()
-            c = Resource(g, curi)
-            concept: Term = None
-            for prefLabel in c.objects(SKOS.prefLabel):
-                if prefLabel.language.startswith(options.lang):
-                    concept: Term = Term(identifier=str(curi), preferredForm=prefLabel.value)
-            if concept:
-                props = defaultdict(list)
-                for altLabel in c.objects(SKOS.altLabel):
-                    if altLabel.language.startswith(options.lang):
-                        props['altForms'].append(altLabel.value)
-                if props:
-                    concept.properties = props
-                yield concept
+        mode = "rb" if options.rdf_format in [RDFFormat.nt, RDFFormat.json_ld] else "r"
+        with maybe_archive(source, mode=mode) as file:
+            thes = g.parse(file=file, format=options.rdf_format)
+            bar.next(20)
+            bar.max = len(list(thes.subjects(predicate=RDF.type, object=SKOS.Concept)))
+            for curi in thes[:RDF.type:SKOS.Concept]:
+                bar.next()
+                c = Resource(g, curi)
+                concept: Term = None
+                for prefLabel in c.objects(SKOS.prefLabel):
+                    if prefLabel.language.startswith(options.lang):
+                        concept: Term = Term(identifier=str(curi), preferredForm=prefLabel.value)
+                if concept:
+                    props = defaultdict(list)
+                    for altLabel in c.objects(SKOS.altLabel):
+                        if altLabel.language.startswith(options.lang):
+                            props['altForms'].append(altLabel.value)
+                    if props:
+                        concept.properties = props
+                    yield concept
         bar.finish()
 
     @classmethod
